@@ -47,6 +47,16 @@ describe PG::Connection do
 		expect( vals ).to eq( [["123"]] )
 	end
 
+	it "connects using 7 arguments in a Ractor", :ractor do
+		vals = Ractor.new do
+			PG.connect( 'localhost', @port, nil, nil, :test, nil, nil ) do |conn|
+				conn.exec("SELECT 234").values
+			end
+		end.take
+
+		expect( vals ).to eq( [["234"]] )
+	end
+
 	describe "#inspect", :without_transaction do
 		it "should print host, port and user of a fresh connection, but not more" do
 			expect( @conn.inspect ).to match(/<PG::Connection:[0-9a-fx]+ host=localhost port=#{@port} user=\w*>/)
@@ -377,7 +387,7 @@ describe PG::Connection do
 				end
 			end
 
-			expect( Time.now - start_time ).to be_between(1.9, 10).inclusive
+			expect( Time.now - start_time ).to be_between(0.9, 10).inclusive
 		end
 	end
 
@@ -578,8 +588,6 @@ describe PG::Connection do
 		end
 
 		it "doesn't notify the wrong thread about closed socket (Bug #564)" do
-			skip "this spec crashs silently on Windows for some reason (pending investigation)" if RUBY_PLATFORM=~/mingw|mswin/i
-
 			10.times do
 				10.times.map do
 					Thread.new do
@@ -1546,6 +1554,17 @@ describe PG::Connection do
 		end
 	end
 
+	it "can connect concurrently in parallel threads", :postgresql_95 do
+		res = 5.times.map do |idx|
+			Thread.new do
+				PG.connect(@conninfo) do |conn|
+					[conn.ssl_in_use?, conn.exec("select 82").getvalue(0, 0)]
+				end
+			end
+		end.map(&:value)
+		expect( res ).to eq( [[true, "82"]] * 5 )
+	end
+
 	describe "deprecated password encryption method" do
 		it "can encrypt password for a given user" do
 			expect( described_class.encrypt_password("postgres", "postgres") ).to match( /\S+/ )
